@@ -55,7 +55,7 @@ class NetsplashSwitchport(Choice):
 
         # the choice initializer creates empty containers
         # for 'access' and 'default' for us
-        super().__init__(['access','default'], choice=choice)
+        super().__init__(['access','default'])
         
         # now we need to fill in everything else
         self.name = Leaf(str)
@@ -64,6 +64,10 @@ class NetsplashSwitchport(Choice):
         self.access.admin_status = Leaf(str)
         self.access.voip_enabled = Leaf(bool)
 
+        # can't apply choice until after we've initialized
+        # all options!
+        if choice:
+            self.choose(choice)
 
 class Devices(NCSInstance):
 
